@@ -138,22 +138,19 @@ pub fn deploy_definitions(tag: &str, definitions: Definitions, replace_existing:
   }
 }
 
-///
-pub fn evaluate_artifact(_ext: &FeelContext, tag: &str, artifact: &str, name: &str) -> Result<Value> {
-  let invoked_artifact = InvokedArtifact::try_from(artifact)?;
+/// Evaluates an artifact.
+pub fn evaluate_artifact(ctx: &FeelContext, model_tag: &str, artifact_type: &str, artifact_name: &str) -> Result<Value> {
   let workspaces = WORKSPACES.lock().unwrap();
-  if let Some(wrk) = workspaces.get("1") {
-    if let Some(_defs) = wrk.get_by_tag(tag) {
-      match invoked_artifact {
-        // FIXME
-        // InvokedArtifact::Decision => return model::eval::eval_decision_by_name(wrk, defs, name, ext),
-        // InvokedArtifact::BusinessKnowledgeModel => {}
-        // InvokedArtifact::DecisionService => return model::eval::eval_decision_service_by_name(wrk, defs, name, ext),
-        _ => {}
+  if let Some(workspace) = workspaces.get("1") {
+    if let Some(definitions) = workspace.get_by_tag(model_tag) {
+      return match InvokedArtifact::try_from(artifact_type)? {
+        InvokedArtifact::Decision => dmntk_evaluator::evaluate_decision_by_name(definitions, artifact_name, ctx),
+        InvokedArtifact::BusinessKnowledgeModel => dmntk_evaluator::evaluate_business_knowledge_model_by_name(definitions, artifact_name, ctx),
+        InvokedArtifact::DecisionService => dmntk_evaluator::evaluate_decision_service_by_name(definitions, artifact_name, ctx),
       };
     }
   }
-  Err(artifact_not_found(artifact.to_owned(), name.to_owned()))
+  Err(artifact_not_found(artifact_type.to_owned(), artifact_name.to_owned()))
 }
 
 /// Errors reported by the workspace.
